@@ -5,7 +5,9 @@
 */
 
 #include "modelverificationpoint.h"
+#include "testhelper.h"
 
+#include <applicationcontroller.h>
 #include <favoritelocationmodel.h>
 #include <locationinformation.h>
 #include <pkpassmanager.h>
@@ -40,30 +42,6 @@ Q_CONSTRUCTOR_FUNCTION(initLocale)
 class TimelineModelTest : public QObject
 {
     Q_OBJECT
-private:
-    void clearPasses(PkPassManager *mgr)
-    {
-        for (const auto &id : mgr->passes()) {
-            mgr->removePass(id);
-        }
-    }
-
-    void clearReservations(ReservationManager *mgr)
-    {
-        const auto batches = mgr->batches(); // copy, as this is getting modified in the process
-        for (const auto &id : batches) {
-            mgr->removeBatch(id);
-        }
-        QCOMPARE(mgr->batches().size(), 0);
-    }
-
-    QByteArray readFile(const QString &fn)
-    {
-        QFile f(fn);
-        f.open(QFile::ReadOnly);
-        return f.readAll();
-    }
-
 private Q_SLOTS:
     void initTestCase()
     {
@@ -109,11 +87,13 @@ private Q_SLOTS:
     void testModel()
     {
         PkPassManager mgr;
-        clearPasses(&mgr);
+        Test::clearAll(&mgr);
         ReservationManager resMgr;
-        clearReservations(&resMgr);
+        Test::clearAll(&resMgr);
+        ApplicationController ctrl;
+        ctrl.setPkPassManager(&mgr);
+        ctrl.setReservationManager(&resMgr);
 
-        resMgr.setPkPassManager(&mgr);
         TimelineModel model;
         QAbstractItemModelTester tester(&model);
         model.setReservationManager(&resMgr);
@@ -141,7 +121,7 @@ private Q_SLOTS:
         QCOMPARE(updateSpy.at(0).at(0).toModelIndex().row(), 0);
         QCOMPARE(model.rowCount(), 2);
 
-        clearReservations(&resMgr);
+        Test::clearAll(&resMgr);
         QCOMPARE(insertSpy.size(), 1);
         QCOMPARE(updateSpy.size(), 1);
         QCOMPARE(rmSpy.size(), 1);
@@ -151,7 +131,9 @@ private Q_SLOTS:
     void testNestedElements()
     {
         ReservationManager resMgr;
-        clearReservations(&resMgr);
+        Test::clearAll(&resMgr);
+        ApplicationController ctrl;
+        ctrl.setReservationManager(&resMgr);
 
         TimelineModel model;
         QAbstractItemModelTester tester(&model);
@@ -167,7 +149,7 @@ private Q_SLOTS:
 
         QCOMPARE(model.rowCount(), 1);
         QCOMPARE(model.index(0, 0).data(TimelineModel::ElementTypeRole), TimelineElement::TodayMarker);
-        resMgr.importReservation(readFile(QLatin1String(SOURCE_DIR "/data/haus-randa-v1.json")));
+        ctrl.importFromUrl(QUrl::fromLocalFile(QLatin1String(SOURCE_DIR "/data/haus-randa-v1.json")));
         QCOMPARE(insertSpy.size(), 3);
         QCOMPARE(insertSpy.at(0).at(1).toInt(), 0);
         QCOMPARE(insertSpy.at(0).at(2).toInt(), 0);
@@ -182,7 +164,7 @@ private Q_SLOTS:
         QCOMPARE(model.index(2, 0).data(TimelineModel::ElementRangeRole), TimelineElement::RangeEnd);
 
         // move end date of a hotel booking: dataChanged on RangeBegin, move (or del/ins) on RangeEnd
-        resMgr.importReservation(readFile(QLatin1String(SOURCE_DIR "/data/haus-randa-v2.json")));
+        ctrl.importFromUrl(QUrl::fromLocalFile(QLatin1String(SOURCE_DIR "/data/haus-randa-v2.json")));
         QCOMPARE(insertSpy.size(), 5);
         QCOMPARE(updateSpy.size(), 1);
         QCOMPARE(rmSpy.size(), 2);
@@ -204,7 +186,9 @@ private Q_SLOTS:
     void testCountryInfos()
     {
         ReservationManager resMgr;
-        clearReservations(&resMgr);
+        Test::clearAll(&resMgr);
+        ApplicationController ctrl;
+        ctrl.setReservationManager(&resMgr);
 
         TimelineModel model;
         QAbstractItemModelTester tester(&model);
@@ -214,7 +198,7 @@ private Q_SLOTS:
         QCOMPARE(model.rowCount(), 1);
         QCOMPARE(model.index(0, 0).data(TimelineModel::ElementTypeRole), TimelineElement::TodayMarker);
 
-        resMgr.importReservation(readFile(QLatin1String(SOURCE_DIR "/data/flight-txl-lhr-sfo.json")));
+        ctrl.importFromUrl(QUrl::fromLocalFile(QLatin1String(SOURCE_DIR "/data/flight-txl-lhr-sfo.json")));
         QCOMPARE(model.rowCount(), 5); //  2x country info, 2x flights, today marker
 
         QCOMPARE(model.index(0, 0).data(TimelineModel::ElementTypeRole), TimelineElement::Flight);
@@ -252,7 +236,7 @@ private Q_SLOTS:
         using namespace KItinerary;
 
         ReservationManager resMgr;
-        clearReservations(&resMgr);
+        Test::clearAll(&resMgr);
         WeatherForecastManager weatherMgr;
         weatherMgr.setTestModeEnabled(true);
 
@@ -404,7 +388,9 @@ private Q_SLOTS:
         using namespace KItinerary;
 
         ReservationManager resMgr;
-        clearReservations(&resMgr);
+        Test::clearAll(&resMgr);
+        ApplicationController ctrl;
+        ctrl.setReservationManager(&resMgr);
         TimelineModel model;
         QAbstractItemModelTester tester(&model);
         model.setReservationManager(&resMgr);
@@ -418,7 +404,7 @@ private Q_SLOTS:
         QVERIFY(rmSpy.isValid());
 
         // full import at runtime
-        resMgr.importReservation(readFile(QLatin1String(SOURCE_DIR "/data/google-multi-passenger-flight.json")));
+        ctrl.importFromUrl(QUrl::fromLocalFile(QLatin1String(SOURCE_DIR "/data/google-multi-passenger-flight.json")));
         QCOMPARE(model.rowCount(), 3); // 2x Flight, 1x TodayMarger
         QCOMPARE(insertSpy.count(), 2);
         QCOMPARE(updateSpy.count(), 2);
@@ -468,7 +454,7 @@ private Q_SLOTS:
         // removal of merged items
         updateSpy.clear();
         rmSpy.clear();
-        clearReservations(&resMgr);
+        Test::clearAll(&resMgr);
         QCOMPARE(model.rowCount(), 1);
         QCOMPARE(rmSpy.count(), 2);
         QCOMPARE(updateSpy.count(), 2);
@@ -477,7 +463,9 @@ private Q_SLOTS:
     void testDayChange()
     {
         ReservationManager resMgr;
-        clearReservations(&resMgr);
+        Test::clearAll(&resMgr);
+        ApplicationController ctrl;
+        ctrl.setReservationManager(&resMgr);
         WeatherForecastManager weatherMgr;
         weatherMgr.setTestModeEnabled(true);
 
@@ -499,7 +487,7 @@ private Q_SLOTS:
         QVERIFY(vp1.verify(&model));
 
         // load something to define the current location, so we get weather
-        resMgr.importReservation(readFile(QLatin1String(SOURCE_DIR "/data/flight-txl-lhr-sfo.json")));
+        ctrl.importFromUrl(QUrl::fromLocalFile(QLatin1String(SOURCE_DIR "/data/flight-txl-lhr-sfo.json")));
         ModelVerificationPoint vp2(QLatin1String(SOURCE_DIR "/data/timeline/daychange-r2.model"));
         vp2.setRoleFilter({TimelineModel::BatchIdRole});
         QVERIFY(vp2.verify(&model));
@@ -527,8 +515,10 @@ private Q_SLOTS:
     {
         QFETCH(QString, baseName);
         ReservationManager resMgr;
-        clearReservations(&resMgr);
-        resMgr.importReservation(readFile(QLatin1String(SOURCE_DIR "/data/timeline/") + baseName + QLatin1String(".json")));
+        Test::clearAll(&resMgr);
+        ApplicationController ctrl;
+        ctrl.setReservationManager(&resMgr);
+        ctrl.importFromUrl(QUrl::fromLocalFile(QLatin1String(SOURCE_DIR "/data/timeline/") + baseName + QLatin1String(".json")));
         TripGroupManager groupMgr;
         groupMgr.setReservationManager(&resMgr);
         WeatherForecastManager weatherMgr;
@@ -568,8 +558,8 @@ private Q_SLOTS:
         QVERIFY(vp.verify(&model));
 
         // retry with loading during runtime
-        clearReservations(&resMgr);
-        resMgr.importReservation(readFile(QLatin1String(SOURCE_DIR "/data/timeline/") + baseName + QLatin1String(".json")));
+        Test::clearAll(&resMgr);
+        ctrl.importFromUrl(QUrl::fromLocalFile(QLatin1String(SOURCE_DIR "/data/timeline/") + baseName + QLatin1String(".json")));
         QVERIFY(vp.verify(&model));
     }
 };
