@@ -31,6 +31,7 @@
 #include "statisticstimerangemodel.h"
 #include "tickettokenmodel.h"
 #include "timelinedelegatecontroller.h"
+#include "transferdelegatecontroller.h"
 #include "transfermanager.h"
 #include "tripgroupinfoprovider.h"
 #include "tripgroupmanager.h"
@@ -115,6 +116,7 @@ void registerApplicationTypes()
     qmlRegisterType<StatisticsTimeRangeModel>("org.kde.itinerary", 1, 0, "StatisticsTimeRangeModel");
     qmlRegisterType<TicketTokenModel>("org.kde.itinerary", 1, 0, "TicketTokenModel");
     qmlRegisterType<TimelineDelegateController>("org.kde.itinerary", 1, 0, "TimelineDelegateController");
+    qmlRegisterType<TransferDelegateController>("org.kde.itinerary", 1, 0, "TransferDelegateController");
     qmlRegisterType<WeatherForecastModel>("org.kde.itinerary", 1, 0, "WeatherForecastModel");
 }
 
@@ -172,15 +174,12 @@ void registerApplicationSingletons()
     REGISTER_SINGLETON_GADGET_FACTORY(NavigationController)
     REGISTER_SINGLETON_GADGET_FACTORY(NotificationConfigController)
     REGISTER_SINGLETON_GADGET_FACTORY(PublicTransport)
-
-    qmlRegisterSingletonType<Util>("org.kde.itinerary", 1, 0, "Util", [](QQmlEngine*, QJSEngine*) -> QObject*{
-        return new Util;
-    });
+    REGISTER_SINGLETON_GADGET_FACTORY(Util)
 }
 
 #undef REGISTER_SINGLETON_INSTANCE
 
-void handlePositionalArguments(ApplicationController *appController, const QStringList &args, bool isTemporary)
+void handleCommandLineArguments(ApplicationController *appController, const QStringList &args, bool isTemporary, const QString &page)
 {
     for (const auto &file : args) {
         const auto localUrl = QUrl::fromLocalFile(file);
@@ -193,6 +192,10 @@ void handlePositionalArguments(ApplicationController *appController, const QStri
             appController->importFromUrl(QUrl::fromUserInput(file));
         }
     }
+
+    if (!page.isEmpty()) {
+        appController->requestOpenPage(page);
+    }
 }
 
 #ifdef Q_OS_ANDROID
@@ -224,12 +227,17 @@ int main(int argc, char **argv)
 
     auto aboutData = KAboutData::applicationData();
     aboutData.setProductName("KDE Itinerary/general"); // Bugzilla product/component name
-    aboutData.setLicense(KAboutLicense::LGPL);
+    aboutData.setLicense(KAboutLicense::LGPL_V2, KAboutLicense::OrLaterVersions);
+    aboutData.setHomepage(QStringLiteral("https://apps.kde.org/itinerary"));
+    aboutData.setShortDescription(i18n("Digital Travel Assistant"));
+    aboutData.setCopyrightStatement(i18n("Copyright © 2018-2021 The KDE Community"));
     KAboutData::setApplicationData(aboutData);
 
     QCommandLineParser parser;
     QCommandLineOption isTemporaryOpt(QStringLiteral("tempfile"), QStringLiteral("Input file is a temporary file and will be deleted after importing."));
     parser.addOption(isTemporaryOpt);
+    QCommandLineOption pageOpt(QStringLiteral("page"), i18n("Open Itinerary on the given page"), QStringLiteral("page"));
+    parser.addOption(pageOpt);
     aboutData.setupCommandLine(&parser);
     parser.addPositionalArgument(QStringLiteral("file"), i18n("PkPass or JSON-LD file to import."));
     parser.process(app);
@@ -249,7 +257,6 @@ int main(int argc, char **argv)
     s_pkPassManager = &passMgr;
 
     ReservationManager resMgr;
-    resMgr.setPkPassManager(&passMgr);
     s_reservationManager = &resMgr;
 
     DocumentManager docMgr;
@@ -280,7 +287,7 @@ int main(int argc, char **argv)
     transferManager.setReservationManager(&resMgr);
     transferManager.setTripGroupManager(&tripGroupMgr);
     transferManager.setFavoriteLocationModel(&favLocModel);
-    transferManager.setPublicTransportManager(liveDataMgr.publicTransportManager());
+    transferManager.setLiveDataManager(&liveDataMgr);
     transferManager.setAutoAddTransfers(settings.autoAddTransfers());
     transferManager.setAutoFillTransfers(settings.autoFillTransfers());
     QObject::connect(&settings, &Settings::autoAddTransfersChanged, &transferManager, &TransferManager::setAutoAddTransfers);
@@ -326,7 +333,7 @@ int main(int argc, char **argv)
         if (!args.isEmpty()) {
             QDir::setCurrent(workingDir);
             parser.parse(args);
-            handlePositionalArguments(&appController, parser.positionalArguments(), parser.isSet(isTemporaryOpt));
+            handleCommandLineArguments(&appController, parser.positionalArguments(), parser.isSet(isTemporaryOpt), parser.value(pageOpt));
         }
         if (!QGuiApplication::allWindows().isEmpty()) {
             QGuiApplication::allWindows().at(0)->requestActivate();
@@ -346,7 +353,8 @@ int main(int argc, char **argv)
     engine.rootContext()->setContextObject(l10nContext);
     engine.load(QStringLiteral("qrc:/main.qml"));
 
-    handlePositionalArguments(&appController, parser.positionalArguments(), parser.isSet(isTemporaryOpt));
+    handleCommandLineArguments(&appController, parser.positionalArguments(), parser.isSet(isTemporaryOpt), parser.value(pageOpt));
+
 #ifdef Q_OS_ANDROID
     using namespace KAndroidExtras;
     appController.importFromIntent(Activity::getIntent());
