@@ -5,6 +5,7 @@
 */
 
 #include "publictransport.h"
+#include "reservationhelper.h"
 #include "logging.h"
 
 #include <KItinerary/BusTrip>
@@ -13,9 +14,8 @@
 #include <KItinerary/Ticket>
 
 #include <KPublicTransport/Attribution>
+#include <KPublicTransport/Backend>
 #include <KPublicTransport/Journey>
-#include <KPublicTransport/Line>
-#include <KPublicTransport/Location>
 #include <KPublicTransport/RentalVehicle>
 #include <KPublicTransport/Stopover>
 #include <KPublicTransport/StopoverRequest>
@@ -88,6 +88,11 @@ KPublicTransport::Location PublicTransport::locationFromPlace(const QVariant& pl
     return loc;
 }
 
+QVariant PublicTransport::trainStationFromLocation(const KPublicTransport::Location &loc) const
+{
+    return PublicTransport::placeFromLocation<KItinerary::TrainStation>(loc);
+}
+
 QString PublicTransport::lineIcon(const QVariant &line) const
 {
     using namespace KPublicTransport;
@@ -160,6 +165,45 @@ QString PublicTransport::rentalVehicleIcon(const KPublicTransport::RentalVehicle
     return QStringLiteral("question");
 }
 
+static QString individualTransportIcon(const KPublicTransport::IndividualTransport &it)
+{
+    using namespace KPublicTransport;
+
+    switch (it.mode()) {
+        case IndividualTransport::Bike:
+             return QStringLiteral("qrc:///images/bike.svg");
+        case IndividualTransport::Car:
+            return QStringLiteral("qrc:///images/car.svg");
+        case IndividualTransport::Walk:
+            return QStringLiteral("qrc:///images/walk.svg");
+    }
+
+    return QStringLiteral("question");
+}
+
+QString PublicTransport::journeySectionIcon(const KPublicTransport::JourneySection &journeySection) const
+{
+    using namespace KPublicTransport;
+    switch (journeySection.mode()) {
+        case JourneySection::Invalid:
+            break;
+        case JourneySection::PublicTransport:
+            return lineIcon(journeySection.route().line());
+        case JourneySection::Walking:
+            return QStringLiteral("qrc:///images/walk.svg");
+        case JourneySection::Waiting:
+            return QStringLiteral("qrc:///images/wait.svg");
+        case JourneySection::Transfer:
+            return QStringLiteral("qrc:///images/transfer.svg");
+        case JourneySection::RentedVehicle:
+            return rentalVehicleIcon(journeySection.rentalVehicle());
+        case JourneySection::IndividualTransport:
+            return individualTransportIcon(journeySection.individualTransport());
+    }
+
+    return QStringLiteral("question");
+}
+
 static KItinerary::Ticket clearSeat(KItinerary::Ticket ticket)
 {
     auto seat = ticket.ticketedSeat();
@@ -291,6 +335,13 @@ QVariant PublicTransport::mergeArrival(const QVariant &res, const KPublicTranspo
     return MergeUtil::merge(newRes, res);
 }
 
+QVariant PublicTransport::mergeJourney(const QVariant &res, const KPublicTransport::JourneySection &journey)
+{
+    auto newRes = mergeDeparture(res, journey.departure());
+    newRes = mergeArrival(newRes, journey.arrival());
+    return newRes;
+}
+
 bool PublicTransport::isSameMode(const QVariant &res, KPublicTransport::Line::Mode mode)
 {
     using namespace KPublicTransport;
@@ -328,9 +379,16 @@ QString PublicTransport::attributionSummary(const QVariantList& attributions) co
     l.reserve(attributions.size());
     for (const auto &v : attributions) {
         const auto attr = v.value<KPublicTransport::Attribution>();
-        l.push_back(QLatin1String("<a href=\"") + attr.url().toString() + QLatin1String("\">") + attr.name() + QLatin1String("</a>"));
+        const auto multi = std::count_if(attributions.begin(), attributions.end(), [attr](const auto &other) {
+            return other.template value<KPublicTransport::Attribution>().name() == attr.name();
+        });
+        if (multi > 1) {
+            l.push_back(QLatin1String("<a href=\"") + attr.url().toString() + QLatin1String("\">") + attr.name() + QLatin1String(" (") + attr.license() + QLatin1String(")</a>"));
+        } else {
+            l.push_back(QLatin1String("<a href=\"") + attr.url().toString() + QLatin1String("\">") + attr.name() + QLatin1String("</a>"));
+        }
     }
-    return l.join(QLatin1String(", "));
+    return QLocale().createSeparatedList(l);
 }
 
 bool PublicTransport::warnAboutSection(const KPublicTransport::JourneySection &section) const
@@ -359,6 +417,17 @@ bool PublicTransport::warnAboutSection(const KPublicTransport::JourneySection &s
                 case RentalVehicle::Car:
                     return false; // ???
             }
+            break;
+        case JourneySection::IndividualTransport:
+            switch (section.individualTransport().mode()) {
+                case IndividualTransport::Walk:
+                    return section.duration() > 20*60 || section.distance() > 1000;
+                case IndividualTransport::Bike:
+                    return section.duration() > 60*60 || section.distance() > 20000;
+                case IndividualTransport::Car:
+                    return false;
+            }
+            break;
     }
 
     return false;
@@ -410,4 +479,75 @@ KPublicTransport::JourneySection PublicTransport::lastTransportSection(const KPu
     return {};
 }
 
+QStringList PublicTransport::suitableBackendsForReservation(KPublicTransport::Manager *mgr, const QVariant &res)
+{
+    using namespace KPublicTransport;
+    QStringList backendIds;
+
+    const auto companyCode = ReservationHelper::uicCompanyCode(res);
+    if (companyCode.size() == 4) {
+        for (const auto &backend : mgr->backends()) {
+            if (!mgr->isBackendEnabled(backend.identifier())) {
+                continue;
+            }
+            for (const auto cov : { CoverageArea::Realtime, CoverageArea::Regular, CoverageArea::Any }) {
+                if (backend.coverageArea(cov).uicCompanyCodes().contains(companyCode)) {
+                    backendIds.push_back(backend.identifier());
+                    break;
+                }
+            }
+        }
+    }
+
+    const auto vdvOrgId = ReservationHelper::vdvOrganizationId(res);
+    if (!vdvOrgId.isEmpty()) {
+        for (const auto &backend : mgr->backends()) {
+            if (!mgr->isBackendEnabled(backend.identifier())) {
+                continue;
+            }
+            for (const auto cov : { CoverageArea::Realtime, CoverageArea::Regular, CoverageArea::Any }) {
+                if (backend.coverageArea(cov).vdvOrganizationIds().contains(vdvOrgId)) {
+                    backendIds.push_back(backend.identifier());
+                    break;
+                }
+            }
+        }
+    }
+
+    return backendIds;
+}
+
+KOSMIndoorMap::Platform::Mode PublicTransport::lineModeToPlatformMode(KPublicTransport::Line::Mode lineMode)
+{
+    using namespace KPublicTransport;
+
+    switch (lineMode) {
+        case Line::Unknown:
+        case Line::Air:
+        case Line::Boat:
+        case Line::Ferry:
+        case Line::Shuttle:
+        case Line::Taxi:
+        case Line::RideShare:
+            return KOSMIndoorMap::Platform::Unknown;
+        case Line::Bus:
+        case Line::BusRapidTransit:
+        case Line::Coach:
+            return KOSMIndoorMap::Platform::Bus;
+        case Line::Funicular:
+        case Line::LocalTrain:
+        case Line::LongDistanceTrain:
+        case Line::RailShuttle:
+        case Line::RapidTransit:
+        case Line::Train:
+            return KOSMIndoorMap::Platform::Rail;
+        case Line::Metro:
+            return KOSMIndoorMap::Platform::Subway;
+        case Line::Tramway:
+            return KOSMIndoorMap::Platform::Tram;
+    }
+
+    return KOSMIndoorMap::Platform::Unknown;
+}
+
 #include "moc_publictransport.cpp"
